@@ -16,10 +16,9 @@ Usage::
     session_client: ComprehendMedicalClient = session.client("comprehendmedical")
     ```
 """
-from mypy_boto3_comprehendmedical.client import (
-    ComprehendMedicalClient,
-    ComprehendMedicalClient as Client,
-)
+from mypy_boto3_comprehendmedical.client import ComprehendMedicalClient
+
+Client = ComprehendMedicalClient
 
 
 __all__ = ("Client", "ComprehendMedicalClient")
